# .citros/parameter_setups/functions

## Function Objects

For a detailed description of function objects, their usage, use cases and relevant examples, please see the documentation [here](https://citros.io/doc/docs_cli/configuration/config_params).

As a demonstration of the usage of user-defined functions, an example file named `my_func.py` is provided, which includes the function `my_awesome_func`, which is pretty awesome.